LoggerConfig

Struct LoggerConfig 

pub struct LoggerConfig {
    pub policy: LogPolicy,
    pub output: LogOutputMode,
    pub file: Option<FileSinkConfig>,
    pub crash_events: usize,
    pub crash_bytes: usize,
}
Complete explicit logger configuration.

Fields

policy: LogPolicy

Filtering and sanitization policy.

output: LogOutputMode

Terminal, file, both, disabled or crash-only behavior.

file: Option<FileSinkConfig>

File configuration used by file output or an explicit crash dump.

crash_events: usize

Maximum events retained by crash-only mode.

crash_bytes: usize

Maximum estimated bytes retained by crash-only mode.

Implementations

Source

impl LoggerConfig

pub fn build(self) -> Result<ConfiguredLogger, LogConfigError>

Builds a logger with no hidden global state or background thread.