pub struct ObservationSnapshot { /* private fields */ }Expand description
Immutable shared view of retained observations, ordered oldest to newest.
Implementations
Sourceimpl ObservationSnapshot
impl ObservationSnapshot
Sourcepub fn iter(&self) -> impl DoubleEndedIterator<Item = &ObservationEvent>
pub fn iter(&self) -> impl DoubleEndedIterator<Item = &ObservationEvent>
Iterates from the oldest observation to the newest without cloning it.
Sourcepub fn recent(&self, limit: usize) -> impl Iterator<Item = &ObservationEvent>
pub fn recent(&self, limit: usize) -> impl Iterator<Item = &ObservationEvent>
Iterates over at most the newest limit observations in chronological order.