pub struct LoggerConfig {
pub policy: LogPolicy,
pub output: LogOutputMode,
pub file: Option<FileSinkConfig>,
pub crash_events: usize,
pub crash_bytes: usize,
}Expand description
Complete explicit logger configuration.
Fields
policy: LogPolicyFiltering and sanitization policy.
output: LogOutputModeTerminal, file, both, disabled or crash-only behavior.
file: Option<FileSinkConfig>File configuration used by file output or an explicit crash dump.
crash_events: usizeMaximum events retained by crash-only mode.
crash_bytes: usizeMaximum estimated bytes retained by crash-only mode.
Implementations
Sourceimpl LoggerConfig
impl LoggerConfig
Sourcepub fn build(self) -> Result<ConfiguredLogger, LogConfigError>
pub fn build(self) -> Result<ConfiguredLogger, LogConfigError>
Builds a logger with no hidden global state or background thread.