pub struct FileObservationSink { /* private fields */ }Expand description
Cloneable non-blocking observation sink backed by a bounded worker queue.
Implementations
Sourceimpl FileObservationSink
impl FileObservationSink
Sourcepub fn new(config: FileObservationSinkConfig) -> Result<Self>
pub fn new(config: FileObservationSinkConfig) -> Result<Self>
Creates the active file and starts the bounded writer worker.
Sourcepub fn stats(&self) -> FileObservationSinkStats
pub fn stats(&self) -> FileObservationSinkStats
Returns worker, backpressure and failure counters.